% Filtros para la reconstruccion de f^k_{2i-1} en AP en el caso SR cuando extendemos desde la izquierda
%     capiacoefimincvpesquerrasr(nl,nr,r)
%     ENTRADAS:
%           nl=numero de nodos a la iquierda de x^{k}_{2i-1}
%           nr=numero de nodos a la derecha de x^{k}_{2i-1}
%           r= grado del polinomio AP
%     SALIDAS:
%           muestra en pantalla los coeficientes que multiplican a f^{k-1} para obtenener f^{k}_{2i-1} mediante AP
%
% Autor: José Jaime Noguera  +INFO: www.uv.es/anims/noguera

function capiacoefimincvpesquerrasr(nl,nr,r)

A=capiamatriumincuad(nl+nr,0,r);
C=(A'*A)^(-1)*A';

for l=1:r+1
   coef(l)=1/(2^(l-1));
end 

solu=coef*C;

format rational
  solu
format
sprintf('Comienza en f^{k-1}_{i+(%d)} y acaba en f^{k-1}_(i-1)',-nl-nr)